# Theme

Theming is about crafting a cohesive visual identity for your application, ensuring a seamless experience for users. It encompasses a harmonious blend of style attributes and reusable components that define the app's aesthetic.

Theming involves several key elements: colors, font sizes, typography, and spacing. All these elements are consolidated within the `src/theme` folder. When starting a new project, exploring this directory is crucial, aligning the values with the intended design.

By leveraging these modules, developers can maintain a consistent typography system across the application while easily managing font assets and styles.

## Colors

In our application, colors are managed through the `src/theme/colors.ts` file. We follow a palette-based methodology to organize our colors effectively. This approach involves defining a cohesive set of colors to be utilized throughout the application. By assigning semantic names to these colors, we ensure consistency and facilitate easy palette adjustments.

This structured approach not only promotes uniformity in our color scheme but also enables seamless modifications to the palette when necessary.

**[Colors README](./Colors.md)**

## Preset Themes

QuickLaunchReactNativeKit offers pre-built themes for convenience.

List of available themes:

| Theme  | Primary Color                                                             |
| ------ | ------------------------------------------------------------------------- |
| Theme1 | ![#AF545B](https://via.placeholder.com/11/AF545B/000000?text=+) `#AF545B` |
| Theme2 | ![#F00001](https://via.placeholder.com/11/F00001/000000?text=+) `#F00001` |
| Theme3 | ![#8034DE](https://via.placeholder.com/11/8034DE/000000?text=+) `#8034DE` |

**[Preset Themes README](./PresetThemes.md)**

## Typography

The Typography Module provides a centralized location for managing font families, font sizes, and line heights used throughout the application.

This README contains a list of supported font families along with instructions on how to add or update font assets.

**[Typography README](./Typography.md)**

## Font Size

The Font Size and Line Height Module defines font sizes and line heights for various text styles used in the application.

This README includes a list of predefined font sizes and their respective line heights, ensuring consistency in typography and spacing.

**[Font Size README](./FontSize.md)**

# Spacing

The Spacing Module provides predefined spacing values for margins, paddings, and other whitespace used throughout the application.

**[Spacing README](./Spacing.md)**
