# Utils

The [Utils](../../../../src/utils) folder encompasses a range of utility functions and components designed to streamline common tasks in QuickLaunchReactNativeKit. Here's a brief overview of each feature included:

## Form Validation

The form validation utility provides a flexible and customizable solution for validating form inputs. By utilizing the `useValidation` hook, developers can easily integrate validation logic into their forms, including support for custom validation rules, error messages, and internationalization.

**[Form Validation README](./FormValidation.md)**

## Toast Message

The Toast message component offers a simple yet effective way to display non-intrusive notifications to users. With customizable options for duration, appearance, and positioning, developers can effortlessly incorporate toast messages into their applications to provide feedback or alerts.

**[Toast Message README](./Toast.md)**

## Scale

The Scale utility facilitates responsive design by offering a standardized approach to scaling dimensions, such as font sizes, spacing, and component sizes, across different screen sizes and devices. By adhering to a consistent scaling strategy, developers can ensure their applications maintain visual coherence and usability across various viewport dimensions.

**[Scale README](./Scale.md)**

## Storage

The Storage utility simplifies data persistence by providing a convenient interface for interacting with browser storage mechanisms, such as local storage and session storage. With methods for reading, writing, and deleting key-value pairs, developers can seamlessly store and retrieve application data client-side, enabling features like user preferences, caching, and offline functionality.

**[Storage README](./Storage.md)**

## useSafeAreaStyles

The useSafeAreaStyles hook helps ensure content remains visually appealing and accessible by dynamically adjusting styles to accommodate safe areas on mobile devices. By accounting for areas of the screen that may be obscured by device-specific features like notches or system bars, developers can create layouts that maximize usable space while maintaining a polished appearance.

**[useSafeAreaStyles README](./useSafeAreaInsetsStyle.md)**

</br>
These utilities collectively contribute to enhancing the development experience and improving the quality and usability of React applications. Whether it's ensuring form inputs are validated accurately, providing unobtrusive feedback to users, or optimizing layouts for various screen sizes, the Utils.md file offers a valuable toolkit for building modern, responsive web applications.
